import { Registry, parseRawGrammar, StackElement, IToken, IGrammar } from 'vscode-textmate';
import { StreamLanguage } from '@codemirror/language';

declare function initializeTextMateRegistry(): Promise<Registry>;

type IRawGrammar = ReturnType<typeof parseRawGrammar>;
interface ParserState {
    ruleStack: StackElement;
    tokensCache: IToken[];
}
declare function createLanguage(scopeName: string, grammar: IGrammar): StreamLanguage<ParserState>;

interface Opts {
    /**
     * This object should not change on rerender. Don't initialize the array inside of the component function.
     */
    textMateGrammars: IRawGrammar[];
}
declare function useTextMateLanguages({ textMateGrammars }: Opts): {
    [scopeName: string]: StreamLanguage<ParserState>;
};

export { IRawGrammar, Opts, ParserState, createLanguage, initializeTextMateRegistry, useTextMateLanguages };
